# Changelog

## 1.0.0-rc1 (2025-10-31)

Full Changelog: [v0.3.0...v1.0.0-rc1](https://github.com/Not-Diamond/not-diamond-python/compare/v0.3.0...v1.0.0-rc1)

### Features

* **api:** fix modelSelect error ([eb29990](https://github.com/Not-Diamond/not-diamond-python/commit/eb29990fab14468f39368f7f5b0e4ebf019d0841))
* **api:** manual updates ([b905d72](https://github.com/Not-Diamond/not-diamond-python/commit/b905d72ebec4d42373de62865a85f62d4a87c477))
* **api:** manual updates ([d664d8d](https://github.com/Not-Diamond/not-diamond-python/commit/d664d8d20ab802a9aa0150519a3900d386f7b1d9))


### Bug Fixes

* **client:** close streams without requiring full consumption ([c9f7310](https://github.com/Not-Diamond/not-diamond-python/commit/c9f73103e1747f06da439c77b7d5e322c4d09a4e))


### Chores

* **internal/tests:** avoid race condition with implicit client cleanup ([14e720b](https://github.com/Not-Diamond/not-diamond-python/commit/14e720b4d735b9a52d634b1ec24db5bff9c3aa24))
* update SDK settings ([26ae314](https://github.com/Not-Diamond/not-diamond-python/commit/26ae3141eaa1df28dd8b1d1e5d322fb135bee6b9))

## 0.3.0 (2025-10-24)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/Not-Diamond/not-diamond-python/compare/v0.2.0...v0.3.0)

### Features

* **api:** api update ([d403264](https://github.com/Not-Diamond/not-diamond-python/commit/d4032647605736f1c51d04023d3adb24f448737f))
* **api:** api update ([c7a1198](https://github.com/Not-Diamond/not-diamond-python/commit/c7a1198c1432e833b740f92df9996379f941228f))
* **api:** api update ([9265a0a](https://github.com/Not-Diamond/not-diamond-python/commit/9265a0a3959818b06f157726e68d3c73f7f5d9c9))
* **api:** api update ([880c195](https://github.com/Not-Diamond/not-diamond-python/commit/880c195dc41ac5e500cae9b9a71b0840f97e7556))
* **api:** exclude non sdk endpoints ([fb04bc4](https://github.com/Not-Diamond/not-diamond-python/commit/fb04bc460d7f9f7f191cffcb56868d09fa45edc1))
* **api:** fix missing endpoint ([427d1d3](https://github.com/Not-Diamond/not-diamond-python/commit/427d1d3bdd7be290e66897aa35daba984931e4a4))
* **api:** manual updates ([603c1b7](https://github.com/Not-Diamond/not-diamond-python/commit/603c1b74c64850e1fd8a89e08b1d66d0665188e0))
* **api:** manual updates ([42fb39e](https://github.com/Not-Diamond/not-diamond-python/commit/42fb39e0978aa329f4b5171ff54aaab257558135))
* **api:** report group ([4312188](https://github.com/Not-Diamond/not-diamond-python/commit/43121880104978fa2b88a3ad0e85070a2b322787))


### Chores

* bump `httpx-aiohttp` version to 0.1.9 ([37d5de2](https://github.com/Not-Diamond/not-diamond-python/commit/37d5de2162ece6024539d9e546dd2679ba5e1882))
* **internal:** detect missing future annotations with ruff ([316a749](https://github.com/Not-Diamond/not-diamond-python/commit/316a7493d166e631eafcc888d377dbe340178b24))

## 0.2.0 (2025-10-09)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/Not-Diamond/not-diamond-python/compare/v0.1.0...v0.2.0)

### Features

* **api:** manual updates ([9ee8b3e](https://github.com/Not-Diamond/not-diamond-python/commit/9ee8b3e1220e45b00ce9c9078ab7f54bb1e34e19))

## 0.1.0 (2025-10-09)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/Not-Diamond/not-diamond-python/compare/v0.0.1...v0.1.0)

### Features

* **api:** manual updates ([8062369](https://github.com/Not-Diamond/not-diamond-python/commit/80623692c7da0db7c57b7953af3ec9fdc1e0fca2))


### Chores

* update SDK settings ([ecc0dc6](https://github.com/Not-Diamond/not-diamond-python/commit/ecc0dc63a8d98e9d2178f04cebde730257bae353))
